abacusai.feature_group_export_config — AbacusAI documentation

# abacusai.feature_group_export_config

## Classes

`FeatureGroupExportConfig` | Export configuration (file connector or database connector information) for feature group exports.

## Module Contents

class abacusai.feature_group_export_config.FeatureGroupExportConfig(client, outputLocation=None, fileFormat=None, databaseConnectorId=None, objectName=None, writeMode=None, databaseFeatureMapping=None, idColumn=None, additionalIdColumns=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Export configuration (file connector or database connector information) for feature group exports.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - outputLocation (str) – The File Connector location to which the feature group is being written.

    - fileFormat (str) – The file format being written to output_location.

    - databaseConnectorId (str) – The unique string identifier of the database connector used.

    - objectName (str) – The object in the database connector to which the feature group is being written.

    - writeMode (str) – UPSERT or INSERT for writing to the database connector.

    - databaseFeatureMapping (dict) – The column/feature pairs mapping the features to the database columns.

    - idColumn (str) – The id column to use as the upsert key.

    - additionalIdColumns (str) – For database connectors which support it, additional ID columns to use as a complex key for upserting.

  output_location
  file_format
  database_connector_id
  object_name
  write_mode
  database_feature_mapping
  id_column
  additional_id_columns
  deprecated_keys
  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict